import sys

from pnplabs.functions import connect, dynamic, instructions, verify_path, get_config
from pnplabs.utils.add_py_scripts_to_path import verify_path_env_set

FUNCTION_NAME_INDEX = 1

STATIC_FUNCTIONS = {
    "connect": connect.execute,
    "verify_path": verify_path.execute,
    "instructions": instructions.execute,
    "get_config": get_config.execute
}

DYNAMIC_FUNCTION = dynamic.execute


def parse(user_args=None):
    if not user_args:
        user_args = sys.argv

    verify_path_env_set()

    if len(user_args) <= 1:
        print("Sorry! Must call pnplabs with a command. For example, try: 'p instructions'")
        return

    required_function = user_args[FUNCTION_NAME_INDEX]
    function_args = user_args[FUNCTION_NAME_INDEX + 1:] if required_function in STATIC_FUNCTIONS else user_args[FUNCTION_NAME_INDEX:]

    # print(f"Required function: {required_function}")
    # print(f"Required args: {function_args}")

    STATIC_FUNCTIONS.get(required_function, DYNAMIC_FUNCTION)(*function_args)



from appdirs import user_data_dir
import configparser
from os import makedirs
import os.path

APP_NAME = "pnplabs"
AUTHOR_NAME = "pnplabs"

USER_COMMANDS_DIR_PATH = os.path.join(user_data_dir(APP_NAME, AUTHOR_NAME), "commands")


def add_commands_dir_to_path():
    pass


def add_script_to_commands_dir():
    pass


def add_command(command):
    os.makedirs(USER_COMMANDS_DIR_PATH, exist_ok=True)
    command_path = os.path.join(USER_COMMANDS_DIR_PATH, command["name"])
    with open(command_path, 'w') as commandfile:
        commandfile.write("test")



from pnplabs.utils.local_config import get_config_as_str, dump_config, USER_CONFIG_PATH


def execute(*args, **kwargs):
    print(f"Here's pnplabs config from path {USER_CONFIG_PATH} :")
    print(get_config_as_str())



def execute(*args, **kwargs):
    print(f"Welcome to pnplabs!")
    print(f"In order to use your commands, first connect with an API Key using the 'connect' command.\n"
          f"Run: 'pnplabs connect <API Key>' using the API Key provided at http://pnplabs.io/getstarted")
